@@ -1,4 +1,5 @@
-import json, socket
+import json, signal, socket
+
 
 class Server:
   def __init__(self, host, port):
@@ -7,7 +8,13 @@ class Server:
     self.server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     self.server_socket.bind((host if host is not None else socket.gethostname(), port))
     self.server_socket.listen()
-  
+
+    def exit_gracefully(*args):
+      self.server_socket.close()
+
+    signal.signal(signal.SIGINT, exit_gracefully)
+    signal.signal(signal.SIGTERM, exit_gracefully)
+
   def _waits_for(self, buffer_size=8192):
     (socket, address) = self.server_socket.accept()
     try:
@@ -19,12 +26,12 @@ class Server:
     except json.decoder.JSONDecodeError:
       print('JSON decode error.')
       return b"{}"
-  
+
   def _encode_json(j):
     return json.dumps(j).encode()
-  
+
   def _decode_json(b):
     return json.loads(b.decode())
-  
+
   def listen(self):
     return Server._decode_json(self._waits_for())
